m_template (zotonic_core v1.0.0-rc.17)

Model for dynamic template rendering. It renders a template path passed in the request path and returns the rendered template output.

Available Model API Paths

MethodPath patternDescription
get/render/...Treat segments after /render/ as the template path, render that template with the payload query args, and return the rendered template output.

/+name marks a variable path segment. A trailing /... means extra path segments are accepted for further lookups.

Summary

Functions

m_get/3