z_config (zotonic_core v1.0.0-rc.17)

Wrapper for Zotonic application environment configuration

Summary

Functions

Get value from config file (cached)

Get value from config file, returning default value when not set (cached).

Copy some zotonic config settings over to other applications

Set a (runtime) config value.

Functions

all()

-spec all() -> [{atom(), term()}].

get(Key)

-spec get(atom()) -> any().

Get value from config file (cached)

Some config settings can be overruled by environment settings.

get(Key, Default)

-spec get(atom(), any()) -> any().

Get value from config file, returning default value when not set (cached).

init_app_env()

-spec init_app_env() -> ok.

Copy some zotonic config settings over to other applications

maybe_map_env(V)

set(Key, Value)

-spec set(atom(), any()) -> ok.

Set a (runtime) config value.