z_edge_log_server (zotonic_core v1.0.0-rc.17)

Check for changed edges, trigger notifications.

Summary

Functions

Force a check, useful after known edge operations.

Convert process state when code is changed

Handling all non call/cast messages

Initiates the server.

Schedule a check if the resource is connected in 12 hours, if not then the resource will be deleted. This is called after a resource is inserted or updated.

Do an edge log check.

Starts the server

This function is called by a gen_server when it is about to terminate. It should be the opposite of Module:init/1 and do any necessary cleaning up. When it returns, the gen_server terminates with Reason. The return value is ignored.

Functions

check(Context)

Force a check, useful after known edge operations.

code_change(OldVsn, State, Extra)

Convert process state when code is changed

delete_if_unconnected(Id, Context)

handle_call(Message, From, State)

Trap unknown calls

handle_cast(Message, State)

handle_info(Info, State)

Handling all non call/cast messages

init(Site)

Initiates the server.

maybe_schedule_dependent_check(Id, Context)

-spec maybe_schedule_dependent_check(Id, Context) -> ok | {error, Reason}
                                        when
                                            Id :: m_rsc:resource_id(),
                                            Context :: z:context(),
                                            Reason :: term().

Schedule a check if the resource is connected in 12 hours, if not then the resource will be deleted. This is called after a resource is inserted or updated.

observe_check_edge_log(_, Context)

Do an edge log check.

start_link(Site)

-spec start_link(atom()) -> {ok, pid()} | ignore | {error, term()}.

Starts the server

terminate(Reason, State)

This function is called by a gen_server when it is about to terminate. It should be the opposite of Module:init/1 and do any necessary cleaning up. When it returns, the gen_server terminates with Reason. The return value is ignored.