z_file_entry (zotonic_core v1.0.0-rc.17)

Process holding information mapping a request path to one or more files. The files can be a static file, a temporary file, cached file or a binary.

Summary

Functions

callback_mode()

content_encoding_gzip(EventType, EventContent, State)

force_stale(Pid)

force_stale(RequestPath, Context)

init(_)

locate(EventType, EventContent, State)

lookup(Pid)

lookup(RequestPath, Context)

pause(Pid)

pause(RequestPath, Context)

paused(EventType, EventContent, State)

serving(EventType, EventContent, State)

start_link(InitialState, RequestPath, Root, OptFilterProps, Context)

stop(Pid)

stop(RequestPath, Context)

stopping(EventType, EventContent, State)

terminate(Reason, StateName, State)

where(Path, Context)