z_filehandler (zotonic_core v1.0.0-rc.17)

Extend the filehandler with mappers for translations, templates and mediaclass.

Summary

Functions

Check if an app file is added, if so we need to tell the module managers and sites to upgrade

Mark a file as modified in the mtime index

A Zotonic template changed

Reload all dispatch rules

Reload translations

Functions

app_file_check(Filename)

Check if an app file is added, if so we need to tell the module managers and sites to upgrade

filehandler_mappers_observer(_, Mappers, Ctx)

mark_modified(Filename)

Mark a file as modified in the mtime index

reindex_modules()

-spec reindex_modules() -> ok.

A Zotonic template changed

reindex_modules_task()

-spec reindex_modules_task() -> ok.

reload_dispatch()

-spec reload_dispatch() -> ok.

Reload all dispatch rules

reload_dispatch_task()

-spec reload_dispatch_task() -> ok.

reload_translations()

-spec reload_translations() -> ok.

Reload translations

reload_translations_task()

-spec reload_translations_task() -> ok.

start_observers()

-spec start_observers() -> ok | {error, term()}.