z_install (zotonic_core v1.0.0-rc.17)

Install Zotonic, loads the datamodel into the database Assumes the database has already been created (which normally needs superuser permissions anyway)

CREATE DATABASE zotonic WITH OWNER = zotonic ENCODING = 'UTF8'; CREATE LANGUAGE "plpgsql";

Summary

Functions

edge_log_function()

edge_log_table()

edge_log_trigger()

hierarchy_index_1()

hierarchy_index_2()

hierarchy_table()

identity_log_table()

install(Context)

-spec install(z:context()) -> ok.

Install the core database tables, triggers and data for the given site.

install_datamodel(Context)

-spec install_datamodel(z:context()) -> ok.

Install only the SQL data model, do not install the data.

medium_log_table()

medium_update_function()

medium_update_trigger()

medium_update_trigger_drop()

rsc_page_path_log()

rsc_page_path_log_fki()

rsc_pivot_log_function()

rsc_pivot_log_index_1()

rsc_pivot_log_index_2()

rsc_pivot_log_table()

rsc_pivot_log_trigger()