z_install_reinstall (zotonic_core v1.0.0-rc.17)

Reinstall the schema for the given site. The site must have valid configuration to fetch the database configuration. The site will be stopped, the schema dropped and then recreated using the usual installer by restarting the site.

Summary

Functions

reinstall(Site)

-spec reinstall(Site) -> ok | {error, Reason} when Site :: atom(), Reason :: term().