z_install_update_task (zotonic_core v1.0.0-rc.17)

Update tasks to be triggered by the z_install_update.erl change routines.

Summary

Functions

Initialize the language column from the language property in the serialized props.

Functions

init_language(Context)

-spec init_language(z:context()) -> ok | {delay, integer(), list()}.

Initialize the language column from the language property in the serialized props.

init_language(Id, Context)

-spec init_language(undefined | integer(), z:context()) -> ok | {delay, integer(), list()}.