z_media_cleanup_server (zotonic_core v1.0.0-rc.17)

Delete medium files that were attached to deleted resources. Files are deleted after 5 weeks, which is the maximum retention period of backups and the default retention period of the filestore. This allows for a recover of deleted media items.

Summary

Functions

cleanup(Context)

Force a cleanup - useful after mass deletes, or when disk space is getting low.

code_change(OldVsn, State, Extra)

handle_call(Message, From, State)

handle_cast(Message, State)

handle_info(Info, State)

init(Site)

start_link(Site)

-spec start_link(atom()) -> {ok, pid()} | ignore | {error, term()}.

Starts the server

terminate(Reason, State)