z_mqtt_ticket (zotonic_core v1.0.0-rc.17)

Tickets for MQTT out of band publish via HTTP

Summary

Functions

Delete a stored context record.

Exchange a ticket for a stored context record.

Return a new ticket id for out of band MQTT calls.

Starts the MQTT ticket server server

Functions

code_change(OldVersion, State, Extra)

delete_ticket(Ticket, Context)

-spec delete_ticket(binary(), z:context()) -> ok | {error, term()}.

Delete a stored context record.

exchange_ticket(Ticket, Context)

-spec exchange_ticket(binary(), z:context()) -> {ok, z:context()} | {error, term()}.

Exchange a ticket for a stored context record.

handle_call(Msg, From, State)

handle_cast(Msg, State)

handle_info(Msg, State)

init(_)

new_ticket(Context)

-spec new_ticket(z:context()) -> {ok, binary()} | {error, term()}.

Return a new ticket id for out of band MQTT calls.

start_link(Site)

Starts the MQTT ticket server server

terminate(Reason, State)