z_site_services_sup (zotonic_core v1.0.0-rc.17)

Supervisor for services for a site. These can be restarted without affecting other parts.

Summary

Functions

Supervisor callback, returns the supervisor tree for the zotonic site services

API for starting the site services supervisor.

Functions

init(Site)

-spec init(atom()) -> {ok, {supervisor:sup_flags(), [supervisor:child_spec()]}}.

Supervisor callback, returns the supervisor tree for the zotonic site services

start_link(Site)

API for starting the site services supervisor.