z_site_sup (zotonic_core v1.0.0-rc.17)

Supervisor for a zotonic site. There are two modi for a site, depending on the site's environment. If a site has environment 'backup' then it is only running the modules backup, base and filestore. The site will be fetching backups from the filestore and importing the SQL dump after it is fetched. In all other environments the site is running with all enabled modules.

Summary

Functions

Supervisor callback, returns the supervisor tree for a zotonic site

Called by z_installer after the database installation is done. We can now start all other site processes.

API for starting the site supervisor.

Functions

init(Site)

-spec init(atom()) -> {ok, {supervisor:sup_flags(), [supervisor:child_spec()]}}.

Supervisor callback, returns the supervisor tree for a zotonic site

install_done(Site)

-spec install_done(atom()) -> ok.

Called by z_installer after the database installation is done. We can now start all other site processes.

install_phase1(Site)

start_link(Site)

-spec start_link(Site :: atom()) -> {ok, pid()} | {error, term()}.

API for starting the site supervisor.