z_sitetest (zotonic_core v1.0.0-rc.17)
Run site-specific tests in an isolated database schema
Summary
Functions
Returns whether the given site is being watched for sitetest runs.
Run all *_sitetest.erl tests for the given site.
Run the given _sitetest eunit modules for the given site.
Stop the sitetests from being run when Erlang modules in the site are recompiled.
Start watching the given site for .erl file changes. As soon as any Erlang module inside the watched site is recompiled, all sitetests are run.
Functions
Returns whether the given site is being watched for sitetest runs.
Run all *_sitetest.erl tests for the given site.
Run the given _sitetest eunit modules for the given site.
Stop the sitetests from being run when Erlang modules in the site are recompiled.
Start watching the given site for .erl file changes. As soon as any Erlang module inside the watched site is recompiled, all sitetests are run.