z_toposort
(zotonic_core v1.0.0-rc.17)
Simple topological sort of tuples {item, [depends], [provides]}
Summary
Return the topological sort of a list of items. Each item lists its provisions and dependencies.
Types
-type cycles() :: [[name()]].
-type topoitem() :: {Name :: name(), Depends :: [atom()], Provides :: [atom()]}.
Functions
Return the topological sort of a list of items. Each item lists its provisions and dependencies.