z_user_agent (zotonic_core v1.0.0-rc.17)

Check if a user agent is a crawler

Summary

Functions

Check if the user agent is probably a bot.

Functions

is_crawler(Context)

-spec is_crawler(string() | binary() | z:context() | undefined) -> boolean().

Check if the user agent is probably a bot.