z_xml (zotonic_core v1.0.0-rc.17)

Utility functions for xml processing.

Summary

Functions

Escape a html text to valid a xml text so that it can be transported in XML. Translates control characters to spaces, except for TAB, CR and LF.

Functions

escape(L)

-spec escape(term()) -> binary().

Escape a html text to valid a xml text so that it can be transported in XML. Translates control characters to spaces, except for TAB, CR and LF.

escape(Trans, Context)