zotonic_core (zotonic_core v1.0.0-rc.17)

Zotonic core - main routines to 'reason' about the current Zotonic installation.

Summary

Functions

Check if the current site is running the testsandbox

Check if this running Zotonic is the main Git project. This is used for e.g. the .pot generation.

Initial setup before starting Zotonic, after config files are loaded. This is normally called by the zotonic_launcher_app, which also reads all config files.

Functions

is_app_available(App)

is_testsandbox()

-spec is_testsandbox() -> boolean().

Check if the current site is running the testsandbox

is_zotonic_project()

Check if this running Zotonic is the main Git project. This is used for e.g. the .pot generation.

setup(Node)

-spec setup(node()) -> ok.

Initial setup before starting Zotonic, after config files are loaded. This is normally called by the zotonic_launcher_app, which also reads all config files.