z_csv_parser (zotonic_core v1.0.0-rc.17)
Parse CSV file into a nested list of lines and fields.
Summary
Functions
Check if the first row is made up of column headers. The file must have at least a name and a category column.
Parse a line into its columns, using a character a separator.
Parse CSV data with the comma separator.
Parse CSV data with a certain separator.
Scan the file (or device) and return lines with fields.
Scan the file (or device) and return lines with fields.
Types
Functions
Check if the first row is made up of column headers. The file must have at least a name and a category column.
-spec inspect_file(file:filename_all()) -> {ok, line(), sep()} | {error, invalid_csv_file | term()}.
Parse a line into its columns, using a character a separator.
Parse CSV data with the comma separator.
Parse CSV data with a certain separator.
-spec scan_lines(file:filename_all() | pid()) -> lines().
Scan the file (or device) and return lines with fields.
-spec scan_lines(file:filename_all() | pid(), sep()) -> lines().
Scan the file (or device) and return lines with fields.