z_edge_log_server (zotonic_core v1.0.0-rc.17)
Check for changed edges, trigger notifications.
Summary
Functions
Force a check, useful after known edge operations.
Convert process state when code is changed
Trap unknown calls
Handling all non call/cast messages
Initiates the server.
Schedule a check if the resource is connected in 12 hours, if not then the resource will be deleted. This is called after a resource is inserted or updated.
Do an edge log check.
Starts the server
This function is called by a gen_server when it is about to terminate. It should be the opposite of Module:init/1 and do any necessary cleaning up. When it returns, the gen_server terminates with Reason. The return value is ignored.
Functions
Force a check, useful after known edge operations.
Convert process state when code is changed
Trap unknown calls
Handling all non call/cast messages
Initiates the server.
-spec maybe_schedule_dependent_check(Id, Context) -> ok | {error, Reason} when Id :: m_rsc:resource_id(), Context :: z:context(), Reason :: term().
Schedule a check if the resource is connected in 12 hours, if not then the resource will be deleted. This is called after a resource is inserted or updated.
Do an edge log check.
Starts the server
This function is called by a gen_server when it is about to terminate. It should be the opposite of Module:init/1 and do any necessary cleaning up. When it returns, the gen_server terminates with Reason. The return value is ignored.