z_file_entry (zotonic_core v1.0.0-rc.17)
Process holding information mapping a request path to one or more files. The files can be a static file, a temporary file, cached file or a binary.
Process holding information mapping a request path to one or more files. The files can be a static file, a temporary file, cached file or a binary.