z_file_sup (zotonic_core v1.0.0-rc.17)
Supervisor for file processes, these processes cache and maintain file information for other file services. They can also resize, combine files and compress files.
Summary
Functions
Flush all cached file entries, needed if some missing files are now present.