z_filehandler (zotonic_core v1.0.0-rc.17)
Extend the filehandler with mappers for translations, templates and mediaclass.
Summary
Functions
Check if an app file is added, if so we need to tell the module managers and sites to upgrade
Mark a file as modified in the mtime index
A Zotonic template changed
Reload all dispatch rules
Reload translations
Functions
Check if an app file is added, if so we need to tell the module managers and sites to upgrade
Mark a file as modified in the mtime index
-spec reindex_modules() -> ok.
A Zotonic template changed
-spec reindex_modules_task() -> ok.
-spec reload_dispatch() -> ok.
Reload all dispatch rules
-spec reload_dispatch_task() -> ok.
-spec reload_translations() -> ok.
Reload translations
-spec reload_translations_task() -> ok.
-spec start_observers() -> ok | {error, term()}.