z_install (zotonic_core v1.0.0-rc.17)
Install Zotonic, loads the datamodel into the database Assumes the database has already been created (which normally needs superuser permissions anyway)
CREATE DATABASE zotonic WITH OWNER = zotonic ENCODING = 'UTF8'; CREATE LANGUAGE "plpgsql";
Summary
Functions
Install the core database tables, triggers and data for the given site.
Install only the SQL data model, do not install the data.