z_install_data (zotonic_core v1.0.0-rc.17)
Initialize the database with start data.
Summary
Functions
Insert boot data into the database.
Reset the resource id sequence to the next max id value.
Functions
Insert boot data into the database.
-spec reset_rsc_id_seq(Context) -> ok when Context :: z:context().
Reset the resource id sequence to the next max id value.