z_install_update (zotonic_core v1.0.0-rc.17)
This server will install the database when started. It will always return ignore to the supervisor. This server should be started after the database pool but before any database queries will be done.
Summary
Functions
Install zotonic on the databases in the PoolOpts, skips when already installed.
Functions
-spec start_link(list()) -> gen_server:start_ret().
Install zotonic on the databases in the PoolOpts, skips when already installed.