z_install_update_task (zotonic_core v1.0.0-rc.17)
Update tasks to be triggered by the z_install_update.erl change routines.
Summary
Functions
Initialize the language column from the language property in the serialized props.
Update tasks to be triggered by the z_install_update.erl change routines.
Initialize the language column from the language property in the serialized props.