zotonic_core
v1.0.0-rc.17
Search documentation of zotonic_core
Default
Default
In-browser search
Settings
z_jsxrecord
(zotonic_core v1.0.0-rc.17)
Define records for JSON encoding
Summary
Functions
init()
Let jsxrecord load the Zotonic record definitions from this module
Functions
init()
Let jsxrecord load the Zotonic record definitions from this module