z_lib_include (zotonic_core v1.0.0-rc.17)
Support for the {% lib filename ... %} tag in the templates. Generates the <link /> or %lt;script /%gt; tag for css or js files. Also adds the greatest modification date so that updates are loaded by the browser.
Summary
Functions
Generate the link and/or script tags for the given files.
Generate the link and/or script tags for the given files.
Given the filepath of the request, return all files collapsed in the path.
Generate urls for the given files, js and css files are separated.
Generate urls for the given files, js and css files are separated.
Types
Functions
Generate the link and/or script tags for the given files.
Generate the link and/or script tags for the given files.
Given the filepath of the request, return all files collapsed in the path.
Generate urls for the given files, js and css files are separated.
Generate urls for the given files, js and css files are separated.