z_logger_formatter (zotonic_core v1.0.0-rc.17)
This is the main module that exposes custom formatting to the OTP logger library (part of the kernel application since OTP-21).
Adapted from logjam, added pretty print of reports and stack traces.
Summary
Types
Functions
-spec format(LogEvent, Config) -> unicode:chardata() when LogEvent :: logger:log_event(), Config :: logger:formatter_config().
-spec format_log(template(), Config, Msg, Meta) -> unicode:chardata() when Config :: logger:formatter_config(), Msg :: Data, Meta :: Data, Data :: #{string() | binary() | atom() => term()}.