z_mqtt_ticket (zotonic_core v1.0.0-rc.17)
Tickets for MQTT out of band publish via HTTP
Summary
Functions
Delete a stored context record.
Exchange a ticket for a stored context record.
Return a new ticket id for out of band MQTT calls.
Starts the MQTT ticket server server
Functions
Delete a stored context record.
Exchange a ticket for a stored context record.
Return a new ticket id for out of band MQTT calls.
Starts the MQTT ticket server server