z_multipart_parse (zotonic_core v1.0.0-rc.17)
Parse multipart/form-data request bodies. Uses a callback function to receive the next parts, can call a progress function to report back the progress on receiving the data.
Adapted from mochiweb_multipart.erl, integrated with webmachine and zotonic
Summary
Functions
Find the next boundary in the data
Receive and parse the form data in the request body. The progress function should accept the parameters [Percentage, Context]
Functions
Find the next boundary in the data
-spec recv_parse(z:context()) -> {#multipart_form{name :: term(), data :: term(), filename :: term(), tmpfile :: term(), tmpmonitor :: term(), content_type :: term(), content_length :: term(), file :: term(), files :: term(), args :: term()}, z:context()}.
Receive and parse the form data in the request body. The progress function should accept the parameters [Percentage, Context]